﻿using System;

using DevExpress.Utils.Serializing.Helpers;

namespace TestProject
{
    /// <summary>
    /// 커스텀 객체 컨버터
    /// </summary>
    public class CustomObjectConverter : ICustomObjectConverter
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 변환 가능 여부 구하기 - CanConvert(type)

        /// <summary>
        /// 변환 가능 여부 구하기
        /// </summary>
        /// <param name="type">타입</param>
        /// <returns>변환 가능 여부</returns>
        public bool CanConvert(Type type)
        {
            return type == typeof(Employee);
        }

        #endregion
        #region 문자열에서 객체 구하기 - FromString(type, source)

        /// <summary>
        /// 문자열에서 객체 구하기
        /// </summary>
        /// <param name="type">타입</param>
        /// <param name="source">소스</param>
        /// <returns>객체</returns>
        public object FromString(Type type, string source)
        {
            if(type != typeof(Employee))
            {
                return null;
            }

            string[] itemArray = source.Split('#');

            if(itemArray.Length >= 3)
            {
                return new Employee(itemArray[0], itemArray[1], int.Parse(itemArray[2]));
            }
            else if(itemArray.Length == 2)
            {
                return new Employee(itemArray[0], itemArray[1], 0);
            }
            else if(itemArray.Length == 1)
            {
                return new Employee(itemArray[0], string.Empty, 0);
            }
            else
            {
                return new Employee(string.Empty, string.Empty, 0);
            }
        }

        #endregion
        #region 문자열 구하기 - ToString(type, source)

        /// <summary>
        /// 문자열 구하기
        /// </summary>
        /// <param name="type">타입</param>
        /// <param name="source">소스</param>
        /// <returns>문자열</returns>
        public string ToString(Type type, object source)
        {
            if(type != typeof(Employee))
            {
                return string.Empty;
            }

            Employee employee = source as Employee;

            return employee.FirstName + '#' + employee.LastName + '#' + employee.Age;
        }

        #endregion
        #region 타입 구하기 - GetType(typeName)

        /// <summary>
        /// 타입 구하기
        /// </summary>
        /// <param name="typeName">타입명</param>
        /// <returns>타입</returns>
        public Type GetType(string typeName)
        {
            if(typeName != typeof(Employee).FullName)
            {
                return null;
            }

            return typeof(Employee);
        }

        #endregion
    }
}