﻿using System;
using System.IO;

using DevExpress.XtraEditors;
using DevExpress.Data.PivotGrid;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 스트림
        /// </summary>
        private MemoryStream stream;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.pivotGridControl.DataSource = Employee.GetDataTable();

            this.pivotGridControl.OptionsData.CustomObjectConverter = new CustomObjectConverter();

            this.saveButton.Click += saveButton_Click;
            this.loadButton.Click += loadButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Save 버튼 클릭시 처리하기 - saveButton_Click(sender, e)

        /// <summary>
        /// Save 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void saveButton_Click(object sender, EventArgs e)
        {
            if(this.stream != null)
            {
                this.stream.Dispose();
            }

            this.stream = new MemoryStream();

            this.pivotGridControl.SavePivotGridToStream(stream);
        }

        #endregion
        #region Load 버튼 클릭시 처리하기 - loadButton_Click(sender, e)

        /// <summary>
        /// Load 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void loadButton_Click(object sender, EventArgs e)
        {
            if(this.stream == null)
            {
                return;
            }

            PivotFileDataSource dataSource = new PivotFileDataSource(this.stream, new CustomObjectConverter());

            this.pivotGridControl.DataSource = dataSource;
        }

        #endregion
    }
}